[![image](http://img.shields.io/pypi/v/idtrackerai.svg)](https://pypi.python.org/pypi/idtrackerai/)
![pipeline](https://gitlab.com/polavieja_lab/idtrackerai/badges/v5-dev/pipeline.svg)
![pylint](https://gitlab.com/polavieja_lab/idtrackerai/-/jobs/artifacts/v5-dev/raw/pylint/pylint.svg?job=test)

Idtracker.ai is a multi-animal tracking software for laboratory conditions. This work has been published in [Nature Methods](https://doi.org/10.1038/s41592-018-0295-5) ([pdf here](https://drive.google.com/file/d/1fYBcmH6PPlwy0AQcr4D0iS2Qd-r7xU9n/view?usp=sharing))

Find everything you are looking for in [our website](https://idtracker.ai)

## Installation for developers.

On an environment with Python 3.10 and a working installation of Pytorch (Torch and Torchvision) you can install idtracker.ai for devs by cloning the repo and installing:

``` bash
git clone https://gitlab.com/polavieja_lab/idtrackerai
pip install -e ./idtrackerai[dev]
```

## Contributors
* Jordi Torrents (2022-)
* Antonio Ortega (2021-)
* Francisco Romero-Ferrero (2015-2022)
* Mattia G. Bergomi (2015-2018)
* Ricardo Ribeiro (2018-2020)
* Francisco J.H. Heras (2015-2022)